summaryrefslogtreecommitdiffstats
path: root/kalyptus/kalyptusCxxToJNI.pm
diff options
context:
space:
mode:
authorMichele Calgaro <michele.calgaro@yahoo.it>2023-07-20 15:05:55 +0900
committerMichele Calgaro <michele.calgaro@yahoo.it>2023-07-20 15:05:55 +0900
commitb9781b38d8fd868d592d6dee0417f6ab0ea57ac5 (patch)
tree4e2073eae14aafbd8acbd65a5c5c668400c2a9f0 /kalyptus/kalyptusCxxToJNI.pm
parent093291ecbc9d8af41de7e06904f1ba3a8b51dfdf (diff)
downloadtdebindings-b9781b38d8fd868d592d6dee0417f6ab0ea57ac5.tar.gz
tdebindings-b9781b38d8fd868d592d6dee0417f6ab0ea57ac5.zip
Replace Q_OBJECT with TQ_OBJECT
Signed-off-by: Michele Calgaro <michele.calgaro@yahoo.it>
Diffstat (limited to 'kalyptus/kalyptusCxxToJNI.pm')
-rw-r--r--kalyptus/kalyptusCxxToJNI.pm4
1 files changed, 2 insertions, 2 deletions
diff --git a/kalyptus/kalyptusCxxToJNI.pm b/kalyptus/kalyptusCxxToJNI.pm
index 1b2ba385..fd426eb8 100644
--- a/kalyptus/kalyptusCxxToJNI.pm
+++ b/kalyptus/kalyptusCxxToJNI.pm
@@ -2625,7 +2625,7 @@ sub preParseClass
|| ($name eq 'qt_cast')
|| ($name eq 'qt_property')
|| ($name eq 'staticMetaObject')
# Assume only Qt classes have tr() and trUtf8() in their Q_OBJECT macro
|| ($classNode->{astNodeName} !~ /^Q/ and $name eq 'tr')
|| ($classNode->{astNodeName} !~ /^Q/ and $name eq 'trUtf8')
|| $name eq 'trUtf8'
@@ -5475,7 +5475,7 @@ sub printJavadocComment($$$$)
$line =~ s/bool/boolean/g;
$line =~ s/SLOT\(\s*([^\)]*)\) ?\)/SLOT("$1)")/g;
$line =~ s/SIGNAL\(\s*([^\)]*)\) ?\)/SIGNAL("$1)")/g;
- $line =~ s/Q_OBJECT\n//g;
+ $line =~ s/TQ_OBJECT\n//g;
$line =~ s/class\s+([\w]+)\s*:\s*public/public class $1 implements/g;
$line =~ s/public\s*(slots)?:\n/public /g;
$line =~ s/([^0-9"]\s*)\*(\s*[^0-9"-])/$1$2/g;
@@ -2625,7 +2625,7 @@ sub preParseClass
|| ($name eq 'qt_property')
|| ($name eq 'staticMetaObject')
- # Assume only Qt classes have tr() and trUtf8() in their Q_OBJECT macro
+ # Assume only Qt classes have tr() and trUtf8() in their TQ_OBJECT macro
|| ($classNode->{astNodeName} !~ /^Q/ and $name eq 'tr')
|| ($classNode->{astNodeName} !~ /^Q/ and $name eq 'trUtf8')